__title__ = "Mock CLI Framework"
__version__ = "0.1.2"
__summary__ = """A framework for creating stand-ins for CLI tools that pretend to be the real thing for when "the real thing" isn't suitable, such as in automated tests."""

"""
See PEP 440 for version scheme
https://www.python.org/dev/peps/pep-0440/#examples-of-compliant-version-schemes
Examples:

FINAL
0.9
0.9.1
0.9.2
...
0.9.10
0.9.11
1.0
1.0.1
1.1
2.0
2.0.1
...

PRE_RELEASES

X.YaN   # Alpha release
X.YbN   # Beta release
X.YrcN  # Release Candidate
X.Y     # Final release
"""
